.. _sync_api:

Sync API Reference
==================

BlackboardSync
--------------

.. automodule:: blackboard_sync.sync
    :members:
    :undoc-members:
    :private-members: _sync_task


BlackboardDownload
------------------

.. automodule:: blackboard_sync.download
    :members:
    :undoc-members:
    :private-members: _create_desktop_link, _handle_file
